Learn R Programming

rms.gof (version 1.0)

test.rms: Computing the root-mean-square test statistic

Description

Calculates the root-mean-square test statistic between the observed data and fully-specified model distribution.

Usage

test.rms(observed, expected)

Arguments

observed
The observed data
expected
The expected data

Details

Called on by rms.pval().

References

"Chi-square and classical exact tests often wildly misreport significance; the remedy lies in computers," by Will Perkins, Mark Tygert, and Rachel Ward.

See Also

rms.pval