rms.gof-package:
Root-mean-square goodness-of-fit test for simple null hypothesis
Description
This package can be used to test any simple null hypothesis using the root-mean-square goodness of fit test. Monte Carlo estimation is used to calculate the associated P-value.
Details
|
Package: |
| rms.gof |
|
Type: |
| Package |
|
Version: |
| 1.0 |
|
Date: |
| 2013-01-15 |
|
License: |
| GPL-3 |
To use this package, the model must be a completely specified discrete probability distribution. The function rms.pval() returns the P-value.References
"Chi-square and classical exact tests often wildly misreport significance; the remedy lies in computers," by Will Perkins, Mark Tygert, and Rachel Ward.